Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(580)

Unified Diff: runtime/vm/object.cc

Issue 489923002: Tweaks to perf jitdump support (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | runtime/vm/os_linux.cc » ('j') | runtime/vm/os_linux.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/object.cc
diff --git a/runtime/vm/object.cc b/runtime/vm/object.cc
index f79dc5898e4a4257805531e7bea40532558d4d01..9960583b9b3665bea01f7526e249074053be708b 100644
--- a/runtime/vm/object.cc
+++ b/runtime/vm/object.cc
@@ -12009,9 +12009,9 @@ RawCode* Code::FinalizeCode(const char* name,
RawCode* Code::FinalizeCode(const Function& function,
Assembler* assembler,
bool optimized) {
// Calling ToFullyQualifiedCString is very expensive, try to avoid it.
if (CodeObservers::AreActive()) {
- return FinalizeCode(function.ToFullyQualifiedCString(),
+ return FinalizeCode(function.ToQualifiedCString(),
assembler,
optimized);
} else {
@@ -12009,9 +12009,9 @@ RawCode* Code::FinalizeCode(const char* name,
Assembler* assembler,
bool optimized) {
- // Calling ToFullyQualifiedCString is very expensive, try to avoid it.
+ // Calling ToQualifiedCString is very expensive, try to avoid it.
if (CodeObservers::AreActive()) {
« no previous file with comments | « no previous file | runtime/vm/os_linux.cc » ('j') | runtime/vm/os_linux.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698